@@ -23,7 +23,7 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <libgames-support.h>
+#include <libgnome-games-support.h>
 
 #include <sys/types.h>
 #include <string.h>
